/*
Example 1.
Data courtesy of Cantonwine, Culbreath, and Stevenson.
See Phytopathology 97: 187-194.
Early leaf spot of peanut (2004, one location [=1]).
Treat:		treatment (1: conventional tillage; 2: strip tillage)
Rep:		label for the replicate (for example, consider these to be 
			randomized plots
Days:		time in days
incidence:	proportion of leaves diseased

Two ways of entering data are shown.
*/
title 'Early leaf spot (Cantonwine et al.), 1 location and year';
data b;
input location	treat	rep	days incidence;
logit = log(incidence/(1-incidence));
gompit = -log(-log(incidence));	 	*--another transformation, not used;
wtlogit=incidence*(1-incidence); 	*--weights, for some analyses;
t = days;							*--sometimes, useful to have a duplicate variable;
datalines;
1	1	1	56	0.079
1	1	2	56	0.115
1	1	3	56	0.148
1	1	4	56	0.116
1	1	1	63	0.783
1	1	2	63	0.391
1	1	3	63	0.593
1	1	4	63	0.738
1	1	1	70	0.593
1	1	2	70	0.508
1	1	3	70	0.500
1	1	4	70	0.579
1	1	1	78	0.757
1	1	2	78	0.676
1	1	3	78	0.735
1	1	4	78	0.721
1	1	1	84	0.944
1	1	2	84	0.825
1	1	3	84	0.917
1	1	4	84	0.913
1	1	1	92	0.894
1	1	2	92	0.938
1	1	3	92	0.909
1	1	4	92	0.917
1	2	1	56	0.097
1	2	2	56	0.129
1	2	3	56	0.061
1	2	4	56	0.016
1	2	1	63	0.111
1	2	2	63	0.306
1	2	3	63	0.103
1	2	4	63	0.159
1	2	1	70	0.176
1	2	2	70	0.127
1	2	3	70	0.286
1	2	4	70	0.125
1	2	1	78	0.520
1	2	2	78	0.506
1	2	3	78	0.318
1	2	4	78	0.377
1	2	1	84	0.833
1	2	2	84	0.493
1	2	3	84	0.631
1	2	4	84	0.375
1	2	1	92	0.831
1	2	2	92	0.881
1	2	3	92	0.878
1	2	4	92	0.870
;

/*Alternate way of reading in data (multivariate format)*/
data mult;
input treat rep y1 y2 y3 y4 y5 y6;
datalines;
1	1	0.079	0.783	0.593	0.757	0.944	0.894
1	2	0.115	0.391	0.508	0.676	0.825	0.938
1	3	0.148	0.593	0.500	0.735	0.917	0.909
1	4	0.116	0.738	0.579	0.721	0.913	0.917
2	1	0.097	0.111	0.176	0.520	0.833	0.831
2	2	0.129	0.306	0.127	0.506	0.493	0.881
2	3	0.061	0.103	0.286	0.318	0.631	0.878
2	4	0.016	0.159	0.125	0.377	0.375	0.870
;
data b2; set mult;  /*Stack the data, duplicating data set b*/
array y{6} y1-y6;
do i = 1 to 6;
incidence = y{i};
*days = tt{i};
output;
end;
drop y1-y6 ;	*--get rid of original variables;
data b2; set b2;  /*Give actual days for temporary code*/
if (i eq 1) then days=56; if (i eq 2) then days=63; if (i eq 3) then days=70;
if (i eq 4) then days=79; if (i eq 5) then days=84; if (i eq 6) then days=91;
t = days;
logit = log(incidence/(1-incidence));
gompit = -log(-log(incidence));
wtlogit=incidence*(1-incidence); drop i;
		*proc print data=b2; run;

*--Now do analyses;
proc mixed data=b covtest ;
title2 'Incorrect: consider DAYS as a between-subject factor (SIMPLE)';
class  treat rep days;
model logit = treat|days  ;
lsmeans treat|days;
run;

proc mixed data=b covtest ;
title2 'Possibly incorrect: DAYS as a true sub-plot(i.e., CS), using RANDOM';
class  treat rep days;
model logit = treat|days;
random rep*treat;		*--could also use RANDOM REP(TREAT);
lsmeans treat|days;
run;

proc mixed data=b covtest ;
title2 'Possibly incorrect: DAYS as a true sub-plot(i.e., CS), using REPEATED';
class  treat rep days;
model logit = treat|days  ;
repeated / subject=rep*treat type=cs;
lsmeans treat|days;
run;

*--^The above two models give same result, IF the correlation within
	subjects is positive (the typical result);

*---Try different "type=" options to find the best fitting covariance matrix.;
*---Some choices: CS, AR(1), UN, CSH, ARH(1), ANTE(1), HF, TOEP(#), TOEPH(#),
	FA(1), FA1(1), ARMA(1,1), etc.;
proc mixed data=b covtest ;
title2 'Repeated Measures, type=UN, ddfm=KR';
class  treat rep days;
model logit = treat|days / ddfm=KR ;
repeated / subject=rep*treat type=un;
lsmeans treat|days / pdiff;			*--pdiff gives all pairs of differences;
lsmeans treat*days / slice=days;	*--slice: tests of treatment at each time;
ods output diffs=diffs;				*--store some output (differences);
run;

data diffs; set diffs;
if (days ne _days) then delete;		*--treatment comparisons on same days;
proc print data=diffs;run;
run;
/*

proc glimmix data=b plots=diffplot ;
title2 'Repeated measures, type=UN, with ddfm=KR';
class  treat rep days;
model logit = treat|days / ddfm=kr ;
random _residual_ / subject=rep*treat type=un;
nloptions tech=nrridg;
lsmeans treat|days / pdiff lines plot=meanplot(sliceby=treat join cl);
run;
*/
/*
proc tabulate data=b;	*--Get arithmetic means (not same as LSMEANS);
class treat days;
var incidence logit;
table days all, mean*logit*(treat all);
run;
*/
run;

/*
*--Now get a variance/covariance vs. lag plot (as on page 187 of Littel et al. (2006);
proc mixed data=b covtest ;
title2 'Repeated Measures, type=UN, ddfm=KR, get cov. graph';
class  treat rep days;
model logit = treat|days / ddfm=KR ;
repeated / subject=rep*treat type=un;
lsmeans treat|days / pdiff;
lsmeans treat*days / slice=days;
ods output diffs=diffs covparms=cov rcorr=corr;
run;
data times;
do time1 = 1 to 6;
	do time2=1 to time1;
	dist=time1-time2;
	output;
	end;
end;
run;
data cov; set cov; if (covparm eq 'block') then delete;
data covplot; merge times cov;
run;
proc print data=covplot; 
run;

axis1 
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2 
               ) 
      label = (angle=90 f=swiss h=2 
             'Covariance of Between Subj Effects');
axis2 order = (0 to 5 by 1)
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2 )
      label = (f=swiss h=2 'Lag');
legend1 value=(font=swiss h=2  ) 
        label=(f=swiss h=2 'From Time')
		across=2
		mode  =protect
        position=(top right inside);
symbol1 color=black interpol=join line=1  value=square; 
symbol2 color=black interpol=join line=2  value=circle; 
symbol3 color=black interpol=join line=20 value=triangle;
symbol4 color=black interpol=join line=3  value=plus; 
symbol5 color=black interpol=join line=4  value=star; 
symbol6 color=black interpol=join line=5  value=dot; 
symbol7 color=black interpol=join line=6  value=_; 
symbol8 color=black interpol=join line=10 value==;

*--Plot shows a general decline in covariance with lag;
proc gplot data=covplot;
   plot estimate*dist=time2 / noframe
                              vaxis  = axis1 
                              haxis  = axis2 
                              legend = legend1;
run;

*/
run;quit;





