/*
Example 1, continued (now known as #3), for time as continuous.
Data courtesy of Cantonwine, Culbreath, and Stevenson.
See Phytopathology 97: 187-194.
Early leaf spot of peanut (2004, one location [=1]).
Treat:		treatment (1: conventional tillage; 2: strip tillage)
Rep:		label for the replicate (randomized plots, assigned to treatment)
Days:		time in days
incidence:	proportion of leaves diseased

Two ways of entering data are shown.
*/
title 'Early leaf spot (Cantonwine et al.), 1 location and year';
data b;
input location	treat	rep	days incidence;
logit = log(incidence/(1-incidence));
gompit = -log(-log(incidence));
wtlogit=incidence*(1-incidence);
t = days; t2=days**2;
datalines;
1	1	1	56	0.079
1	1	2	56	0.115
1	1	3	56	0.148
1	1	4	56	0.116
1	1	1	63	0.783
1	1	2	63	0.391
1	1	3	63	0.593
1	1	4	63	0.738
1	1	1	70	0.593
1	1	2	70	0.508
1	1	3	70	0.500
1	1	4	70	0.579
1	1	1	78	0.757
1	1	2	78	0.676
1	1	3	78	0.735
1	1	4	78	0.721
1	1	1	84	0.944
1	1	2	84	0.825
1	1	3	84	0.917
1	1	4	84	0.913
1	1	1	92	0.894
1	1	2	92	0.938
1	1	3	92	0.909
1	1	4	92	0.917
1	2	1	56	0.097
1	2	2	56	0.129
1	2	3	56	0.061
1	2	4	56	0.016
1	2	1	63	0.111
1	2	2	63	0.306
1	2	3	63	0.103
1	2	4	63	0.159
1	2	1	70	0.176
1	2	2	70	0.127
1	2	3	70	0.286
1	2	4	70	0.125
1	2	1	78	0.520
1	2	2	78	0.506
1	2	3	78	0.318
1	2	4	78	0.377
1	2	1	84	0.833
1	2	2	84	0.493
1	2	3	84	0.631
1	2	4	84	0.375
1	2	1	92	0.831
1	2	2	92	0.881
1	2	3	92	0.878
1	2	4	92	0.870
;

/*Alternate way of reading in data (multivariate format)*/
data mult;
input treat rep y1 y2 y3 y4 y5 y6;
datalines;
1	1	0.079	0.783	0.593	0.757	0.944	0.894
1	2	0.115	0.391	0.508	0.676	0.825	0.938
1	3	0.148	0.593	0.500	0.735	0.917	0.909
1	4	0.116	0.738	0.579	0.721	0.913	0.917
2	1	0.097	0.111	0.176	0.520	0.833	0.831
2	2	0.129	0.306	0.127	0.506	0.493	0.881
2	3	0.061	0.103	0.286	0.318	0.631	0.878
2	4	0.016	0.159	0.125	0.377	0.375	0.870
;
data b2; set mult;  /*Stack the data, duplicating data set b*/
array y{6} y1-y6;
do i = 1 to 6;
incidence = y{i};
output;
end;
drop y1-y6 ;
data b2; set b2;  /*Give actual days for temporary code*/
if (i eq 1) then days=56; if (i eq 2) then days=63; if (i eq 3) then days=70;
if (i eq 4) then days=79; if (i eq 5) then days=84; if (i eq 6) then days=91;
t = days; t2=t**2;
logit = log(incidence/(1-incidence));
gompit = -log(-log(incidence));
wtlogit=incidence*(1-incidence); drop i;
*proc print data=b2; run;

*--Consider time as continuous;
proc mixed data=b covtest ;
title2 'Repeated Measures, type=UN, ddfm=KR, covariance analysis';
class  treat rep days;						*---Time (t) is NOT a factor;
model logit = treat|t / ddfm=KR solution ;	*--SOLUTION for all coeffs.;
repeated / subject=rep*treat type=un;
estimate 'interc1' int 1 treat 1 0;
estimate 'interc2' int 1 treat 0 1;
estimate 'slope1' t 1 treat*t 1 0;
estimate 'slope2' t 1 treat*t 0 1;
estimate 'int1-int2' treat 1 -1;
estimate 'slope1-slope2' treat*t 1 -1;
run;

proc mixed data=b covtest ;
title2 'Repeated Measures, type=UN, ddfm=KR, covariance analysis';
title3 'Get intercepts and slopes directly (do NOT use F tests)';
class  treat rep days;
model logit = treat treat*t / ddfm=KR solution noint;
	*---In model^, drop t term, and add noint option;
	*---Get the intercepts and slopes directly, but don't use F tests;
repeated / subject=rep*treat type=un;
run;
title3;
run;

run;quit;
/*Note: one can use LSMEANS to compare treatment means, but one
cannot obtain LSMEANS for interactions with t (because t is now
continuous, the concept does not make sense). For the default,
the statement
	LSMEANS treat / pdiff;
gets means and differences at t=0. If there is an 
interaction of treatment and t, then it might make more sense
to get means at some other value of t (because the difference
of means will depend on t. One can do this with:
	LSMEANS treat / pdiff at t=40;
as an example.
*/

run;

